@@ -39,11 +39,23 @@ class Null(object):
     def __init__(self, *args, **kwargs): pass
     def __call__(self, *args, **kwargs): return self
     def __repr__(self): return self.__class__.__name__
+    def __len__(self): return 0
     def __nonzero__(self): return 0
     def __eq__(self, other): return isinstance(other, self.__class__)
     def __ne__(self, other): return not isinstance(other, self.__class__)
+    def __contains__(self, item): return False
     def __getattr__(self, name): return self
-    def __setattr__(self, name, value): return self
-    def __delattr__(self, name): return self
+    def __setattr__(self, name, value): pass
+    def __delattr__(self, name): pass
+    def __getitem__(self, key): return self
+    def __setitem__(self, key, value): pass
+    def __delitem__(self, key): pass
+    def __get__(self, obj, type): return self
+    def __set__(self, obj, value): pass
+    def __delete__(self, obj): pass
+    def __enter__(self): return self
+    def __exit__(self, exc_type, exc_value, traceback): pass
+    def __iter__(self): return self
+    def next(self): raise StopIteration
     __str__ = __repr__
 
